#[repr(transparent)]pub struct VTFrameProcessorError(pub NSInteger);objc2 and VTFrameProcessorErrors only.Expand description
VTFrameProcessor error codes.
These error codes are returned in the NSError object in the event a method fails.
See also Apple’s documentation
Tuple Fields
0: NSIntegerImplementations
Sourceimpl VTFrameProcessorError
impl VTFrameProcessorError
Sourcepub const UnknownError: Self
pub const UnknownError: Self
Returned if the processor failed for unknown reason.
Sourcepub const UnsupportedResolution: Self
pub const UnsupportedResolution: Self
Returned if the processor failed due to an unsupported resolution.
Sourcepub const SessionNotStarted: Self
pub const SessionNotStarted: Self
Returned if the session is used to process frames without being started.
Sourcepub const SessionAlreadyActive: Self
pub const SessionAlreadyActive: Self
Returned if a startSessionWithConfiguration call is made on a session which has already been started.
Sourcepub const FatalError: Self
pub const FatalError: Self
Returned if a fatal error is encoutnered during processing.
Sourcepub const SessionLevelError: Self
pub const SessionLevelError: Self
Returned if processing failed and current session should be stopped.
Sourcepub const InitializationFailed: Self
pub const InitializationFailed: Self
Returned if the session failed to initialize the processing pipeline.
Sourcepub const UnsupportedInput: Self
pub const UnsupportedInput: Self
Returned to indicate that one or more frames is in a format which is not supproted by the processor.
Sourcepub const MemoryAllocationFailure: Self
pub const MemoryAllocationFailure: Self
Returned if the session or processor is unable to allocate required memory.
Sourcepub const RevisionNotSupported: Self
pub const RevisionNotSupported: Self
Returned if the specifed revision is not supported by the configured processor.
Sourcepub const ProcessingError: Self
pub const ProcessingError: Self
Returned if the processor encountered an issue preventing it from processing the provided frame.
Sourcepub const InvalidParameterError: Self
pub const InvalidParameterError: Self
Returned if one of the provided parameters is not valid.
Sourcepub const InvalidFrameTiming: Self
pub const InvalidFrameTiming: Self
Returned if one of the provided VTFrameProcessorFrame objects has a presentation time which is not supported by the processor, either invalid or out-of-order.
Sourcepub const AssetDownloadFailed: Self
pub const AssetDownloadFailed: Self
Returned if download of a required model asset for the processor failed